# This file was auto-generated by Fern from our API Definition.

from . import pet, store, user
from .pet import FindPetsByStatusRequestStatus

__all__ = ["FindPetsByStatusRequestStatus", "pet", "store", "user"]



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx

from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import PetstoreApiEnvironment
from .resources.pet.client import AsyncPetClient, PetClient
from .resources.store.client import AsyncStoreClient, StoreClient
from .resources.user.client import AsyncUserClient, UserClient


class PetstoreApi:
    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: PetstoreApiEnvironment = PetstoreApiEnvironment.DEFAULT,
        api_key: str,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        timeout: typing.Optional[float] = 60,
        httpx_client: typing.Optional[httpx.Client] = None
    ):
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            token=token,
            httpx_client=httpx.Client(timeout=timeout) if httpx_client is None else httpx_client,
        )
        self.pet = PetClient(client_wrapper=self._client_wrapper)
        self.store = StoreClient(client_wrapper=self._client_wrapper)
        self.user = UserClient(client_wrapper=self._client_wrapper)


class AsyncPetstoreApi:
    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: PetstoreApiEnvironment = PetstoreApiEnvironment.DEFAULT,
        api_key: str,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        timeout: typing.Optional[float] = 60,
        httpx_client: typing.Optional[httpx.AsyncClient] = None
    ):
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            api_key=api_key,
            token=token,
            httpx_client=httpx.AsyncClient(timeout=timeout) if httpx_client is None else httpx_client,
        )
        self.pet = AsyncPetClient(client_wrapper=self._client_wrapper)
        self.store = AsyncStoreClient(client_wrapper=self._client_wrapper)
        self.user = AsyncUserClient(client_wrapper=self._client_wrapper)


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: PetstoreApiEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

from .types import Address, ApiResponse, Category, Customer, OauthScope, Order, OrderStatus, Pet, PetStatus, Tag, User
from .errors import BadRequestError, NotFoundError
from .resources import FindPetsByStatusRequestStatus, pet, store, user
from .environment import PetstoreApiEnvironment

__all__ = [
    "Address",
    "ApiResponse",
    "BadRequestError",
    "Category",
    "Customer",
    "FindPetsByStatusRequestStatus",
    "NotFoundError",
    "OauthScope",
    "Order",
    "OrderStatus",
    "Pet",
    "PetStatus",
    "PetstoreApiEnvironment",
    "Tag",
    "User",
    "pet",
    "store",
    "user",
]



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class FindPetsByStatusRequestStatus(str, enum.Enum):
    AVAILABLE = "available"
    PENDING = "pending"
    SOLD = "sold"

    def visit(
        self,
        available: typing.Callable[[], T_Result],
        pending: typing.Callable[[], T_Result],
        sold: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is FindPetsByStatusRequestStatus.AVAILABLE:
            return available()
        if self is FindPetsByStatusRequestStatus.PENDING:
            return pending()
        if self is FindPetsByStatusRequestStatus.SOLD:
            return sold()



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...errors.bad_request_error import BadRequestError
from ...errors.not_found_error import NotFoundError
from ...types.order import Order

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class StoreClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_inventory(self) -> typing.Dict[str, int]:
        """
        Returns a map of status codes to quantities

        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.store.get_inventory()
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "store/inventory"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.Dict[str, int], _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def place_order(self, *, request: Order) -> Order:
        """
        Place a new order in the store

        Parameters:
            - request: Order.
        ---
        from Petstore import Order
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.store.place_order(
            request=Order(
                id=1,
                pet_id=1,
                quantity=1,
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "store/order"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Order, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_order_by_id(self, order_id: int) -> Order:
        """
        For valid response try integer IDs with value <= 5 or > 10. Other values will generate exceptions.

        Parameters:
            - order_id: int. ID of order that needs to be fetched
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.store.get_order_by_id(
            order_id=1,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"store/order/{order_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Order, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_order(self, order_id: int) -> None:
        """
        For valid response try integer IDs with value < 1000. Anything above 1000 or nonintegers will generate API errors

        Parameters:
            - order_id: int. ID of the order that needs to be deleted
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.store.delete_order(
            order_id=1,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"store/order/{order_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncStoreClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_inventory(self) -> typing.Dict[str, int]:
        """
        Returns a map of status codes to quantities

        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.store.get_inventory()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "store/inventory"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.Dict[str, int], _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def place_order(self, *, request: Order) -> Order:
        """
        Place a new order in the store

        Parameters:
            - request: Order.
        ---
        from Petstore import Order
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.store.place_order(
            request=Order(
                id=1,
                pet_id=1,
                quantity=1,
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "store/order"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Order, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_order_by_id(self, order_id: int) -> Order:
        """
        For valid response try integer IDs with value <= 5 or > 10. Other values will generate exceptions.

        Parameters:
            - order_id: int. ID of order that needs to be fetched
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.store.get_order_by_id(
            order_id=1,
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"store/order/{order_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Order, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_order(self, order_id: int) -> None:
        """
        For valid response try integer IDs with value < 1000. Anything above 1000 or nonintegers will generate API errors

        Parameters:
            - order_id: int. ID of the order that needs to be deleted
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.store.delete_order(
            order_id=1,
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"store/order/{order_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...core.remove_none_from_dict import remove_none_from_dict
from ...errors.bad_request_error import BadRequestError
from ...errors.not_found_error import NotFoundError
from ...types.user import User

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class UserClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def create_user(self, *, request: User) -> None:
        """
        This can only be done by the logged in user.

        Parameters:
            - request: User.
        ---
        from Petstore import User
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.create_user(
            request=User(
                id=1,
                username="theUser",
                first_name="John",
                last_name="James",
                email="john@email.com",
                user_status=1,
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_users_with_list_input(self, *, request: typing.List[User]) -> User:
        """
        Creates list of users with given input array

        Parameters:
            - request: typing.List[User].
        ---
        from Petstore import User
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.create_users_with_list_input(
            request=[
                User(
                    id=1,
                    username="theUser",
                    first_name="John",
                    last_name="James",
                    email="john@email.com",
                    user_status=1,
                )
            ],
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user/createWithList"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(User, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def login_user(self, *, username: typing.Optional[str] = None, password: typing.Optional[str] = None) -> str:
        """


        Parameters:
            - username: typing.Optional[str]. The user name for login

            - password: typing.Optional[str]. The password for login in clear text
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.login_user()
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user/login"),
            params=remove_none_from_dict({"username": username, "password": password}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(str, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def logout_user(self) -> None:
        """


        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.logout_user()
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user/logout"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_user_by_name(self, username: str) -> User:
        """


        Parameters:
            - username: str. The name that needs to be fetched. Use user1 for testing.
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.get_user_by_name(
            username="username",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"user/{username}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(User, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_user(self, username: str, *, request: User) -> None:
        """
        This can only be done by the logged in user.

        Parameters:
            - username: str. name that needs to be updated

            - request: User.
        ---
        from Petstore import User
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.update_user(
            username="username",
            request=User(
                id=1,
                username="theUser",
                first_name="John",
                last_name="James",
                email="john@email.com",
                user_status=1,
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "PUT",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"user/{username}"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_user(self, username: str) -> None:
        """
        This can only be done by the logged in user.

        Parameters:
            - username: str. The name that needs to be deleted
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.user.delete_user(
            username="username",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"user/{username}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncUserClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def create_user(self, *, request: User) -> None:
        """
        This can only be done by the logged in user.

        Parameters:
            - request: User.
        ---
        from Petstore import User
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.create_user(
            request=User(
                id=1,
                username="theUser",
                first_name="John",
                last_name="James",
                email="john@email.com",
                user_status=1,
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_users_with_list_input(self, *, request: typing.List[User]) -> User:
        """
        Creates list of users with given input array

        Parameters:
            - request: typing.List[User].
        ---
        from Petstore import User
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.create_users_with_list_input(
            request=[
                User(
                    id=1,
                    username="theUser",
                    first_name="John",
                    last_name="James",
                    email="john@email.com",
                    user_status=1,
                )
            ],
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user/createWithList"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(User, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def login_user(self, *, username: typing.Optional[str] = None, password: typing.Optional[str] = None) -> str:
        """


        Parameters:
            - username: typing.Optional[str]. The user name for login

            - password: typing.Optional[str]. The password for login in clear text
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.login_user()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user/login"),
            params=remove_none_from_dict({"username": username, "password": password}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(str, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def logout_user(self) -> None:
        """


        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.logout_user()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "user/logout"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_user_by_name(self, username: str) -> User:
        """


        Parameters:
            - username: str. The name that needs to be fetched. Use user1 for testing.
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.get_user_by_name(
            username="username",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"user/{username}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(User, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_user(self, username: str, *, request: User) -> None:
        """
        This can only be done by the logged in user.

        Parameters:
            - username: str. name that needs to be updated

            - request: User.
        ---
        from Petstore import User
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.update_user(
            username="username",
            request=User(
                id=1,
                username="theUser",
                first_name="John",
                last_name="James",
                email="john@email.com",
                user_status=1,
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "PUT",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"user/{username}"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_user(self, username: str) -> None:
        """
        This can only be done by the logged in user.

        Parameters:
            - username: str. The name that needs to be deleted
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.user.delete_user(
            username="username",
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"user/{username}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrderStatus(str, enum.Enum):
    """
    Order Status
    """

    PLACED = "placed"
    APPROVED = "approved"
    DELIVERED = "delivered"

    def visit(
        self,
        placed: typing.Callable[[], T_Result],
        approved: typing.Callable[[], T_Result],
        delivered: typing.Callable[[], T_Result],
    ) -> T_Result:
        if self is OrderStatus.PLACED:
            return placed()
        if self is OrderStatus.APPROVED:
            return approved()
        if self is OrderStatus.DELIVERED:
            return delivered()



# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OauthScope(str, enum.Enum):
    WRITE_PETS = "write:pets"
    """
    modify pets in your account
    """

    READ_PETS = "read:pets"
    """
    read your pets
    """

    def visit(self, write_pets: typing.Callable[[], T_Result], read_pets: typing.Callable[[], T_Result]) -> T_Result:
        if self is OauthScope.WRITE_PETS:
            return write_pets()
        if self is OauthScope.READ_PETS:
            return read_pets()



# This file was auto-generated by Fern from our API Definition.

import typing

import httpx


class BaseClientWrapper:
    def __init__(
        self, *, api_key: str, token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None, base_url: str
    ):
        self._api_key = api_key
        self._token = token
        self._base_url = base_url

    def get_headers(self) -> typing.Dict[str, str]:
        headers: typing.Dict[str, str] = {
            "X-Fern-Language": "Python",
            "X-Fern-SDK-Name": "petstore",
            "X-Fern-SDK-Version": "0.0.2",
        }
        headers["api_key"] = self._api_key
        token = self._get_token()
        if token is not None:
            headers["Authorization"] = f"Bearer {token}"
        return headers

    def _get_token(self) -> typing.Optional[str]:
        if isinstance(self._token, str) or self._token is None:
            return self._token
        else:
            return self._token()

    def get_base_url(self) -> str:
        return self._base_url


class SyncClientWrapper(BaseClientWrapper):
    def __init__(
        self,
        *,
        api_key: str,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        base_url: str,
        httpx_client: httpx.Client,
    ):
        super().__init__(api_key=api_key, token=token, base_url=base_url)
        self.httpx_client = httpx_client


class AsyncClientWrapper(BaseClientWrapper):
    def __init__(
        self,
        *,
        api_key: str,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        base_url: str,
        httpx_client: httpx.AsyncClient,
    ):
        super().__init__(api_key=api_key, token=token, base_url=base_url)
        self.httpx_client = httpx_client



# This file was auto-generated by Fern from our API Definition.

import typing
import urllib.parse
from json.decoder import JSONDecodeError

from ...core.api_error import ApiError
from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.jsonable_encoder import jsonable_encoder
from ...core.remove_none_from_dict import remove_none_from_dict
from ...errors.bad_request_error import BadRequestError
from ...errors.not_found_error import NotFoundError
from ...types.api_response import ApiResponse
from ...types.pet import Pet
from .types.find_pets_by_status_request_status import FindPetsByStatusRequestStatus

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class PetClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def add_pet(self, *, request: Pet) -> Pet:
        """
        Add a new pet to the store

        Parameters:
            - request: Pet.
        ---
        from Petstore import Pet
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.add_pet(
            request=Pet(
                id=1,
                name="doggie",
                photo_urls=["photoUrls"],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Pet, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_pet(self, *, request: Pet) -> Pet:
        """
        Update an existing pet by Id

        Parameters:
            - request: Pet.
        ---
        from Petstore import Pet
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.update_pet(
            request=Pet(
                id=1,
                name="doggie",
                photo_urls=["photoUrls"],
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "PUT",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Pet, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def find_pets_by_status(self, *, status: typing.Optional[FindPetsByStatusRequestStatus] = None) -> typing.List[Pet]:
        """
        Multiple status values can be provided with comma separated strings

        Parameters:
            - status: typing.Optional[FindPetsByStatusRequestStatus]. Status values that need to be considered for filter
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.find_pets_by_status()
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet/findByStatus"),
            params=remove_none_from_dict({"status": status}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.List[Pet], _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def find_pets_by_tags(
        self, *, tags: typing.Optional[typing.Union[str, typing.List[str]]] = None
    ) -> typing.List[Pet]:
        """
        Multiple tags can be provided with comma separated strings. Use tag1, tag2, tag3 for testing.

        Parameters:
            - tags: typing.Optional[typing.Union[str, typing.List[str]]]. Tags to filter by
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.find_pets_by_tags()
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet/findByTags"),
            params=remove_none_from_dict({"tags": tags}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.List[Pet], _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_pet_by_id(self, pet_id: int) -> Pet:
        """
        Returns a single pet

        Parameters:
            - pet_id: int. ID of pet to return
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.get_pet_by_id(
            pet_id=1,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Pet, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def update_pet_with_form(
        self, pet_id: int, *, name: typing.Optional[str] = None, status: typing.Optional[str] = None
    ) -> None:
        """


        Parameters:
            - pet_id: int. ID of pet that needs to be updated

            - name: typing.Optional[str]. Name of pet that needs to be updated

            - status: typing.Optional[str]. Status of pet that needs to be updated
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.update_pet_with_form(
            pet_id=1,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}"),
            params=remove_none_from_dict({"name": name, "status": status}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_pet(self, pet_id: int) -> None:
        """


        Parameters:
            - pet_id: int. Pet id to delete
        ---
        from Petstore.client import PetstoreApi

        client = PetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        client.pet.delete_pet(
            pet_id=1,
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def upload_file(self, pet_id: int, *, request: bytes) -> ApiResponse:
        """


        Parameters:
            - pet_id: int. ID of pet to update

            - request: bytes.
        """
        _response = self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}/uploadImage"),
            content=request,
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ApiResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncPetClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def add_pet(self, *, request: Pet) -> Pet:
        """
        Add a new pet to the store

        Parameters:
            - request: Pet.
        ---
        from Petstore import Pet
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.add_pet(
            request=Pet(
                id=1,
                name="doggie",
                photo_urls=["photoUrls"],
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Pet, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_pet(self, *, request: Pet) -> Pet:
        """
        Update an existing pet by Id

        Parameters:
            - request: Pet.
        ---
        from Petstore import Pet
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.update_pet(
            request=Pet(
                id=1,
                name="doggie",
                photo_urls=["photoUrls"],
            ),
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "PUT",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet"),
            json=jsonable_encoder(request),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Pet, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def find_pets_by_status(
        self, *, status: typing.Optional[FindPetsByStatusRequestStatus] = None
    ) -> typing.List[Pet]:
        """
        Multiple status values can be provided with comma separated strings

        Parameters:
            - status: typing.Optional[FindPetsByStatusRequestStatus]. Status values that need to be considered for filter
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.find_pets_by_status()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet/findByStatus"),
            params=remove_none_from_dict({"status": status}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.List[Pet], _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def find_pets_by_tags(
        self, *, tags: typing.Optional[typing.Union[str, typing.List[str]]] = None
    ) -> typing.List[Pet]:
        """
        Multiple tags can be provided with comma separated strings. Use tag1, tag2, tag3 for testing.

        Parameters:
            - tags: typing.Optional[typing.Union[str, typing.List[str]]]. Tags to filter by
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.find_pets_by_tags()
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", "pet/findByTags"),
            params=remove_none_from_dict({"tags": tags}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(typing.List[Pet], _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_pet_by_id(self, pet_id: int) -> Pet:
        """
        Returns a single pet

        Parameters:
            - pet_id: int. ID of pet to return
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.get_pet_by_id(
            pet_id=1,
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "GET",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(Pet, _response.json())  # type: ignore
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        if _response.status_code == 404:
            raise NotFoundError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def update_pet_with_form(
        self, pet_id: int, *, name: typing.Optional[str] = None, status: typing.Optional[str] = None
    ) -> None:
        """


        Parameters:
            - pet_id: int. ID of pet that needs to be updated

            - name: typing.Optional[str]. Name of pet that needs to be updated

            - status: typing.Optional[str]. Status of pet that needs to be updated
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.update_pet_with_form(
            pet_id=1,
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}"),
            params=remove_none_from_dict({"name": name, "status": status}),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_pet(self, pet_id: int) -> None:
        """


        Parameters:
            - pet_id: int. Pet id to delete
        ---
        from Petstore.client import AsyncPetstoreApi

        client = AsyncPetstoreApi(
            api_key="YOUR_API_KEY",
            token="YOUR_TOKEN",
        )
        await client.pet.delete_pet(
            pet_id=1,
        )
        """
        _response = await self._client_wrapper.httpx_client.request(
            "DELETE",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}"),
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return
        if _response.status_code == 400:
            raise BadRequestError(pydantic.parse_obj_as(typing.Any, _response.json()))  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def upload_file(self, pet_id: int, *, request: bytes) -> ApiResponse:
        """


        Parameters:
            - pet_id: int. ID of pet to update

            - request: bytes.
        """
        _response = await self._client_wrapper.httpx_client.request(
            "POST",
            urllib.parse.urljoin(f"{self._client_wrapper.get_base_url()}/", f"pet/{pet_id}/uploadImage"),
            content=request,
            headers=self._client_wrapper.get_headers(),
            timeout=60,
        )
        if 200 <= _response.status_code < 300:
            return pydantic.parse_obj_as(ApiResponse, _response.json())  # type: ignore
        try:
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from .address import Address
from .api_response import ApiResponse
from .category import Category
from .customer import Customer
from .oauth_scope import OauthScope
from .order import Order
from .order_status import OrderStatus
from .pet import Pet
from .pet_status import PetStatus
from .tag import Tag
from .user import User

__all__ = [
    "Address",
    "ApiResponse",
    "Category",
    "Customer",
    "OauthScope",
    "Order",
    "OrderStatus",
    "Pet",
    "PetStatus",
    "Tag",
    "User",
]
